/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {useModal} from '@clayui/modal';
import PropTypes from 'prop-types';
import React, {useState} from 'react';

import ChainedRedirectionsModal from './ChainedRedirectionsModal';

function ChainedRedirections({portletNamespace, ...restProps}) {
	const [redirectEntryChainCause, setRedirectEntryChainCause] = useState(
		null
	);
	const [showModal, setShowModal] = useState(false);
	const [callback, setCallback] = useState();
	const BRIDGE_COMPONENT_ID = `${portletNamespace}RedirectsChainedRedirections`;

	const handleOnClose = () => {
		setShowModal(false);
	};

	const {observer, onClose} = useModal({
		onClose: handleOnClose,
	});

	if (!Liferay.component(BRIDGE_COMPONENT_ID)) {
		Liferay.component(
			BRIDGE_COMPONENT_ID,
			{
				open: (redirectEntryChainCause, callback) => {
					setCallback(() => callback);
					setRedirectEntryChainCause(redirectEntryChainCause);
					setShowModal(true);
				},
			},
			{
				destroyOnNavigate: true,
			}
		);
	}

	return (
		<>
			{showModal && (
				<ChainedRedirectionsModal
					{...restProps}
					callback={callback}
					observer={observer}
					onModalClose={onClose}
					redirectEntryChainCause={redirectEntryChainCause}
				/>
			)}
		</>
	);
}

ChainedRedirections.propTypes = {
	portletNamespace: PropTypes.string.isRequired,
};

export default function (props) {
	return (
		<ChainedRedirections
			{...props}
			portletNamespace={`_${props.portletNamespace}_`}
		/>
	);
}
